@@ -4,10 +4,15 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::Portability;
 # ABSTRACT: Release tests for portability
-our $VERSION = '2.000005'; # VERSION
+our $VERSION = '2.000006'; # VERSION
 use Moose;
-extends 'Dist::Zilla::Plugin::InlineFiles';
-with 'Dist::Zilla::Role::FileMunger';
+with qw/
+    Dist::Zilla::Role::FileGatherer
+    Dist::Zilla::Role::FileInjector
+    Dist::Zilla::Role::TextTemplate
+/;
+use Dist::Zilla::File::InMemory;
+use Data::Section -setup;
 
 
 
@@ -18,23 +23,28 @@ has options => (
 );
 
 
-sub munge_file {
-    my ($self, $file) = @_;
-    return unless $file->name eq 'xt/release/portability.t';
+sub gather_files {
+    my $self = shift;
 
     # 'name => val, name=val'
     my %options = split(/\W+/, $self->options);
 
-    if ( keys %options ) {
-        my $content = $file->content;
-
-        my $optstr = join ', ', map { "$_ => $options{$_}" } sort keys %options;
-
-        # insert options() above run_tests;
-        $content =~ s/^(run_tests\(\);)$/options($optstr);\n$1/m;
-
-        $file->content($content);
+    my $opts = '';
+    if (%options) {
+        $opts = join ', ', map { "$_ => $options{$_}" } sort keys %options;
+        $opts = "options($opts);";
     }
+
+    my $filename = 'xt/release/portability.t';
+    my $content  = $self->section_data($filename);
+    my $filled_content = $self->fill_in_string( $$content, { opts => $opts } );
+    $self->add_file(
+        Dist::Zilla::File::InMemory->new({
+            name => $filename,
+            content => $filled_content,
+        })
+    );
+
     return;
 }
 
@@ -44,7 +54,7 @@ no Moose;
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -52,7 +62,7 @@ Dist::Zilla::Plugin::Test::Portability - Release tests for portability
 
 =head1 VERSION
 
-version 2.000005
+version 2.000006
 
 =head1 SYNOPSIS
 
@@ -81,6 +91,8 @@ Inserts the given options into the generated test file.
 =for test_synopsis 1;
 __END__
 
+=for Pod::Coverage gather_files
+
 =head1 AVAILABILITY
 
 The project homepage is L<http://metacpan.org/release/Dist-Zilla-Plugin-Test-Portability/>.
@@ -138,4 +150,5 @@ use Test::More;
 eval 'use Test::Portability::Files';
 plan skip_all => 'Test::Portability::Files required for testing portability'
     if $@;
+{{$opts}}
 run_tests();
